param(
[Parameter(Position=0,Mandatory=$true)] $XinkCredential,
[Parameter(Position=1,Mandatory=$true)] $DomainFileName
)

$xinkAPIRoot = "https://e.xink.io"

[Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12

Write-Host -NoNewline "Obtaining Xink API access token..."
Try
{
	$body = [System.Text.Encoding]::UTF8.GetBytes('grant_type=client_credentials&client_id='+$XinkCredential.UserName+'&client_secret='+$XinkCredential.GetNetworkCredential().Password+'&scope=reroutingcfgctrl') 
	$response = Invoke-RestMethod -Method 'POST' -Uri "https://auth.xink.io/OAuth/Token" -ContentType 'application/x-www-form-urlencoded' -Body $body
	Write-Host "OK."
	$xinkToken = $response.access_token
}
Catch
{
	Write-Host "FAILED, "$_
	Break
}

Write-Host -NoNewline "Obtaining Xink API Root..."
Try
{
	$response = Invoke-RestMethod -Method 'GET' -Uri "https://auth.xink.io/Discovery" -Headers @{Authorization =("Bearer "+ $xinkToken)}
	Write-Host "OK."
	Write-Host "Datacenter ID:" $response.DataCenterID
	$xinkAPIRoot = $response.APIRoot
}
Catch
{
	Write-Host "FAILED, "$_
	Break
}


Write-Host "Mapping accepted domains in Office 365..."
Try
{
	if(!(Test-Path $DomainFileName -PathType Leaf))
	{
		Write-Warning "File $DomainFileName was not found."
	}
	$domains = Get-Content $DomainFileName 2>$null
	if($domains -And $domains.Count -gt 0)
	{
		Write-Host "Domain list from the file:"
		$submitMap = @();
		foreach($domain in $domains)
		{
			# add to Xink map
			$submitMap += @{ 
				DomainName = "$domain"
				IsDomainDefault = $false
			}
			Write-Host $domain
		}
		Write-Host "--- end of list ---"
		
		Write-Host -NoNewline "Submitting domain map to Xink..."
		$submitMapResponse = Invoke-RestMethod -Method 'POST' -Uri $xinkAPIRoot"/api/1.0/rerouting/replacemap" -Headers @{Authorization =("Bearer "+ $xinkToken)} -Body (ConvertTo-Json $submitMap)	-ContentType "application/json"
			
		if($submitMapResponse.StatusCode -eq 0){
			Write-Host "OK."
		} else {
			Write-Host "SUBMIT FAILED:"$submitMapResponse.ErrorMessage
			Break
		}
		
	}
	else
	{
		Write-Host "No domains found."
	}
}
Catch
{
	Write-Host "FAILED."$_
	Break
}

